summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGravatar Alexandre Alapetite <alexandre@alapetite.fr> 2013-11-16 22:41:03 +0100
committerGravatar Alexandre Alapetite <alexandre@alapetite.fr> 2013-11-16 22:41:03 +0100
commit4a2b17d54ab3714c4f567a43a7a2e701cd9a7b49 (patch)
treed3fa2b91aaa334a8e16f0aaa33aa144f282219c6
parente13c6439d5ed02d1fe19ece070445f5f58b63e44 (diff)
Minz : nouveau Minz_Log::DEBUG
Nouveau niveau Minz_Log::DEBUG pour plus de finesse dans les messages
-rwxr-xr-xapp/controllers/configureController.php2
-rwxr-xr-xapp/controllers/feedController.php12
-rwxr-xr-xapp/controllers/indexController.php4
-rw-r--r--lib/minz/Minz_Log.php23
-rwxr-xr-xpublic/index.php5
-rw-r--r--public/themes/default/freshrss.css4
-rw-r--r--public/themes/flat-design/freshrss.css12
7 files changed, 38 insertions, 24 deletions
diff --git a/app/controllers/configureController.php b/app/controllers/configureController.php
index 815f3f5f4..2856bb89f 100755
--- a/app/controllers/configureController.php
+++ b/app/controllers/configureController.php
@@ -302,7 +302,7 @@ class configureController extends ActionController {
Request::_param ('feeds', $feeds);
Request::forward (array ('c' => 'feed', 'a' => 'massiveImport'));
} catch (OpmlException $e) {
- Minz_Log::record ($e->getMessage (), Minz_Log::ERROR);
+ Minz_Log::record ($e->getMessage (), Minz_Log::WARNING);
$notif = array (
'type' => 'bad',
diff --git a/app/controllers/feedController.php b/app/controllers/feedController.php
index 0ba82631c..e54a2ac12 100755
--- a/app/controllers/feedController.php
+++ b/app/controllers/feedController.php
@@ -105,14 +105,14 @@ class feedController extends ActionController {
$params['id'] = $feed->id ();
}
} catch (BadUrlException $e) {
- Minz_Log::record ($e->getMessage (), Minz_Log::ERROR);
+ Minz_Log::record ($e->getMessage (), Minz_Log::WARNING);
$notif = array (
'type' => 'bad',
'content' => Translate::t ('invalid_url', $url)
);
Session::_param ('notification', $notif);
} catch (FeedException $e) {
- Minz_Log::record ($e->getMessage (), Minz_Log::ERROR);
+ Minz_Log::record ($e->getMessage (), Minz_Log::WARNING);
$notif = array (
'type' => 'bad',
'content' => Translate::t ('internal_problem_feed')
@@ -159,9 +159,9 @@ class feedController extends ActionController {
$nb_month_old = $this->view->conf->oldEntries ();
$date_min = time () - (60 * 60 * 24 * 30 * $nb_month_old);
if (rand(0, 30) === 1) {
- Minz_Log::record ('CleanOldEntries', Minz_Log::NOTICE); //TODO: Remove
+ Minz_Log::record ('CleanOldEntries', Minz_Log::DEBUG);
if ($entryDAO->cleanOldEntries ($date_min) > 0) {
- Minz_Log::record ('UpdateCachedValues', Minz_Log::NOTICE); //TODO: Remove
+ Minz_Log::record ('UpdateCachedValues', Minz_Log::DEBUG);
$feedDAO->updateCachedValues ();
}
}
@@ -196,7 +196,7 @@ class feedController extends ActionController {
$feedDAO->commit ();
$flux_update++;
} catch (FeedException $e) {
- Minz_Log::record ($e->getMessage (), Minz_Log::ERROR);
+ Minz_Log::record ($e->getMessage (), Minz_Log::NOTICE);
$feedDAO->updateLastUpdate ($feed->id (), 1);
}
@@ -298,7 +298,7 @@ class feedController extends ActionController {
}
} catch (FeedException $e) {
$error = true;
- Minz_Log::record ($e->getMessage (), Minz_Log::ERROR);
+ Minz_Log::record ($e->getMessage (), Minz_Log::WARNING);
}
}
diff --git a/app/controllers/indexController.php b/app/controllers/indexController.php
index 10c29bc7b..224d6fb9e 100755
--- a/app/controllers/indexController.php
+++ b/app/controllers/indexController.php
@@ -123,7 +123,7 @@ class indexController extends ActionController {
// Si on a récupéré aucun article "non lus"
// on essaye de récupérer tous les articles
if ($state === 'not_read' && $entries->isEmpty ()) { //TODO: Remove in v0.8
- Minz_Log::record ('Conflicting information about nbNotRead!', Minz_Log::NOTICE); //TODO: Consider adding a Minz_Log::DEBUG level
+ Minz_Log::record ('Conflicting information about nbNotRead!', Minz_Log::DEBUG);
$this->view->state = 'all';
$getter->_state ('all');
$getter->execute ();
@@ -131,7 +131,7 @@ class indexController extends ActionController {
}
$this->view->entryPaginator = $entries;
- } catch(EntriesGetterException $e) {
+ } catch (EntriesGetterException $e) {
Minz_Log::record ($e->getMessage (), Minz_Log::NOTICE);
Error::error (
404,
diff --git a/public/index.php b/public/index.php
index dc6da259d..1a1651707 100755
--- a/public/index.php
+++ b/public/index.php
@@ -54,8 +54,9 @@ if (file_exists (PUBLIC_PATH . '/install.php')) {
$front_controller = new App_FrontController ();
$front_controller->init ();
$front_controller->run ();
- } catch (PDOConnectionException $e) {
+ } catch (Exception $e) {
+ echo '### Fatal error! ###<br />', "\n";
Minz_Log::record ($e->getMessage (), Minz_Log::ERROR);
- print '### Application problem ###<br />'."\n".'See logs files';
+ echo 'See logs files.';
}
}
diff --git a/public/themes/default/freshrss.css b/public/themes/default/freshrss.css
index 81ff6d196..c8231f93d 100644
--- a/public/themes/default/freshrss.css
+++ b/public/themes/default/freshrss.css
@@ -677,6 +677,10 @@
background: #f4f4f4;
color: #aaa;
}
+ .log.debug {
+ background: #111;
+ color: #eee;
+ }
.form-group table {
border-collapse:collapse;
diff --git a/public/themes/flat-design/freshrss.css b/public/themes/flat-design/freshrss.css
index 498a02c1e..ef59abb4d 100644
--- a/public/themes/flat-design/freshrss.css
+++ b/public/themes/flat-design/freshrss.css
@@ -658,21 +658,25 @@ body {
color: #666;
font-size: 90%;
}
- .log .date {
+ .log>.date {
margin: 0 10px 0 0;
padding: 5px 10px;
border-radius: 20px;
}
- .log.error .date {
+ .log.error>.date {
background: #e74c3c;
color: #fff;
}
- .log.warning .date {
+ .log.warning>.date {
background: #f39c12;
}
- .log.notice .date {
+ .log.notice>.date {
background: #ecf0f1;
}
+ .log.debug>.date {
+ background: #111;
+ color: #eee;
+ }
.form-group table {
border-collapse:collapse;
diff --git a/lib/minz/Minz_Log.php b/lib/minz/Minz_Log.php
index 153870435..e66cc040b 100644
--- a/lib/minz/Minz_Log.php
+++ b/lib/minz/Minz_Log.php
@@ -12,11 +12,13 @@ class Minz_Log {
* Les différents niveau de log
* ERROR erreurs bloquantes de l'application
* WARNING erreurs pouvant géner le bon fonctionnement, mais non bloquantes
* NOTICE messages d'informations, affichés pour le déboggage
*/
- const ERROR = 0;
- const WARNING = 10;
- const NOTICE = 20;
+ const ERROR = 2;
+ const WARNING = 4;
+ const NOTICE = 8;
+ const DEBUG = 16;
/**
* Enregistre un message dans un fichier de log spécifique
@@ -31,9 +33,9 @@ class Minz_Log {
public static function record ($information, $level, $file_name = null) {
$env = Configuration::environment ();
- if (! ($env == Configuration::SILENT
- || ($env == Configuration::PRODUCTION
- && ($level == Minz_Log::WARNING || $level == Minz_Log::NOTICE)))) {
+ if (! ($env === Configuration::SILENT
+ || ($env === Configuration::PRODUCTION
+ && ($level <= Minz_Log::NOTICE)))) {
if (is_null ($file_name)) {
$file_name = LOG_PATH . '/application.log';
}
@@ -48,6 +50,9 @@ class Minz_Log {
case Minz_Log::NOTICE :
$level_label = 'notice';
break;
+ case Minz_Log::DEBUG :
+ $level_label = 'debug';
+ break;
default :
$level_label = 'unknown';
}
@@ -83,7 +88,7 @@ class Minz_Log {
$msg_get = str_replace("\n", '', '$_GET content : ' . print_r($_GET, true));
$msg_post = str_replace("\n", '', '$_POST content : ' . print_r($_POST, true));
- self::record($msg_get, Minz_Log::NOTICE, $file_name);
- self::record($msg_post, Minz_Log::NOTICE, $file_name);
+ self::record($msg_get, Minz_Log::DEBUG, $file_name);
+ self::record($msg_post, Minz_Log::DEBUG, $file_name);
}
}
@@ -12,11 +12,13 @@ class Minz_Log {
* ERROR erreurs bloquantes de l'application
* WARNING erreurs pouvant géner le bon fonctionnement, mais non bloquantes
- * NOTICE messages d'informations, affichés pour le déboggage
+ * NOTICE erreurs mineures ou messages d'informations
+ * DEBUG Informations affichées pour le déboggage
*/